@@ -1,38 +1,31 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  begin:     Fri Sep 03 2004
-  copyright: (C) 2004 by John Tapsell
-  email:     john@geola.co.uk
+    SPDX-FileCopyrightText: 2004 John Tapsell <john@geola.co.uk>
 */
 
 #include "serverison.h"
 #include "server.h"
 #include "application.h"
-#include "nickinfo.h"
 #include "viewcontainer.h"
+#include "konversation_log.h"
 
 ServerISON::ServerISON(Server* server) : m_server(server)
 {
     m_ISONList_invalid = true;
 
-    connect( m_server, SIGNAL(nickInfoChanged(Server*,NickInfoPtr)),
-        this, SLOT(nickInfoChanged(Server*,NickInfoPtr)));
+    connect( m_server, QOverload<Server*, NickInfoPtr>::of(&Server::nickInfoChanged),
+        this, &ServerISON::nickInfoChanged);
     connect( m_server,
-        SIGNAL(channelMembersChanged(Server*,QString,bool,bool,QString)),
+        &Server::channelMembersChanged,
         this,
-        SLOT(slotChannelMembersChanged(Server*,QString,bool,bool,QString)));
+        &ServerISON::slotChannelMembersChanged);
     connect( m_server,
-        SIGNAL(channelJoinedOrUnjoined(Server*,QString,bool)),
+        &Server::channelJoinedOrUnjoined,
         this,
-        SLOT(slotChannelJoinedOrUnjoined(Server*,QString,bool)));
-    connect(Application::instance(), SIGNAL(serverGroupsChanged(Konversation::ServerGroupSettingsPtr)),
-        this, SLOT(slotServerGroupsChanged()));
+        &ServerISON::slotChannelJoinedOrUnjoined);
+    connect(Application::instance(), &Application::serverGroupsChanged,
+        this, &ServerISON::slotServerGroupsChanged);
 }
 
 QStringList ServerISON::getWatchList()
@@ -56,13 +49,11 @@ void ServerISON::recalculateAddressees()
     {
         QMap<QString,QString> ISONMap;
 
-        QStringList prefsWatchList =
+        const QStringList prefsWatchList =
             Preferences::notifyListByGroupId(m_server->getServerGroup()->id());
-        QStringList::iterator itEnd = prefsWatchList.end();
 
-        for(QStringList::iterator it = prefsWatchList.begin(); it != itEnd; ++it)
-        {
-            ISONMap.insert((*it).toLower(), (*it));
+        for (const QString& prefsWatch : prefsWatchList) {
+            ISONMap.insert(prefsWatch.toLower(), prefsWatch);
         }
 
         // Build final watch list.
@@ -70,13 +61,10 @@ void ServerISON::recalculateAddressees()
         // Eliminate nicks that are online in a joined channel, since there is no point
         // in doing an ISON on such nicks.
         m_ISONList.clear();
-        itEnd = m_watchList.end();
 
-        for(QStringList::iterator it = m_watchList.begin(); it != itEnd; ++it)
-        {
-            if (m_server->getNickJoinedChannels(*it).isEmpty())
-            {
-                m_ISONList.append(*it);
+        for (const QString& nickName : qAsConst(m_watchList)) {
+            if (m_server->getNickJoinedChannels(nickName).isEmpty()) {
+                m_ISONList.append(nickName);
             }
         }
     }
@@ -91,11 +79,11 @@ void ServerISON::recalculateAddressees()
 // When user changes preferences and has nick watching turned on, rebuild notify list.
 void ServerISON::slotServerGroupsChanged()
 {
-    qDebug();
+    qCDebug(KONVERSATION_LOG) << __FUNCTION__;
     m_ISONList_invalid = true;
 }
 
-void ServerISON::nickInfoChanged(Server* /*server*/, const NickInfoPtr /*nickInfo*/) {
+void ServerISON::nickInfoChanged(Server* /*server*/, const NickInfoPtr /*nickInfo*/&) {
 //We need to call recalculateAddressees before returning m_ISONList
 
 //Maybe we could do something like:
