@@ -51,7 +51,7 @@ KonsolePanel::KonsolePanel(QWidget *p) : ChatWindow( p ), k_part (nullptr)
     KService::Ptr service = KService::serviceByDesktopName(QStringLiteral("konsolepart"));
     if( service )
     {
-        fact = KPluginLoader(service->library()).factory();
+        fact = KPluginFactory::loadFactory(KPluginMetaData(service->library())).plugin;
     }
 
     if (!fact) return;
